
# This file was generated by 'versioneer.py' (0.19) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2025-04-16T22:35:59-0400",
 "dirty": true,
 "error": null,
 "full-revisionid": "f64e628f1502e4a7c7045e517a74550c9d5cd661",
 "version": "2.59.2b1"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
